#ifndef NT2_INCLUDE_FUNCTIONS_MAXNUMMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAXNUMMAG_HPP_INCLUDED

#include <nt2/ieee/include/functions/maxnummag.hpp>

#endif
